"""Exception classes for Chzzk SDK."""

from chzzk.exceptions.errors import (
    AuthenticationError,
    ChatConnectionError,
    ChatNotLiveError,
    ChatReconnectError,
    ChzzkAPIError,
    ChzzkError,
    CookieAuthenticationError,
    EventSubscriptionError,
    ForbiddenError,
    InvalidClientError,
    InvalidStateError,
    InvalidTokenError,
    NotFoundError,
    RateLimitError,
    ServerError,
    SessionConnectionError,
    SessionError,
    SessionLimitExceededError,
    TokenExpiredError,
    UnofficialAPIError,
)

__all__ = [
    "AuthenticationError",
    "ChatConnectionError",
    "ChatNotLiveError",
    "ChatReconnectError",
    "ChzzkAPIError",
    "ChzzkError",
    "CookieAuthenticationError",
    "EventSubscriptionError",
    "ForbiddenError",
    "InvalidClientError",
    "InvalidStateError",
    "InvalidTokenError",
    "NotFoundError",
    "RateLimitError",
    "ServerError",
    "SessionConnectionError",
    "SessionError",
    "SessionLimitExceededError",
    "TokenExpiredError",
    "UnofficialAPIError",
]
